# Open Law Library _Partners_

This is the public package for the Open Law Library Partners module.

If you need access to the module, please contact [info@openlawlib.org][1].

[1]: mailto:info@openlawlib.org